@@ -12,7 +12,6 @@
 
 namespace BluezQt
 {
-
 GattCharacteristic::GattCharacteristic(const QString &uuid, GattService *service)
     : QObject(service)
     , d(new GattCharacterisiticPrivate(uuid, service))
@@ -36,7 +35,7 @@ QByteArray GattCharacteristic::readValue()
 void GattCharacteristic::writeValue(const QByteArray &value)
 {
     d->m_value = value;
-    emit valueWritten(d->m_value);
+    Q_EMIT valueWritten(d->m_value);
 }
 
 QString GattCharacteristic::uuid() const
@@ -60,3 +59,5 @@ void GattCharacteristic::setReadCallback(ReadCallback callback)
 }
 
 } // namespace BluezQt
+
+#include "moc_gattcharacteristic.cpp"
