@@ -7,20 +7,18 @@
  */
 
 #include "obexmanager.h"
-#include "obexmanager_p.h"
-#include "initobexmanagerjob.h"
 #include "debug.h"
-#include "pendingcall.h"
+#include "initobexmanagerjob.h"
 #include "obexagent.h"
 #include "obexagentadaptor.h"
-#include "obexsession.h"
+#include "obexmanager_p.h"
+#include "pendingcall.h"
 #include "utils.h"
 
 #include <QDBusServiceWatcher>
 
 namespace BluezQt
 {
-
 ObexManager::ObexManager(QObject *parent)
     : QObject(parent)
     , d(new ObexManagerPrivate(this))
@@ -55,7 +53,7 @@ QList<ObexSessionPtr> ObexManager::sessions() const
 
 ObexSessionPtr ObexManager::sessionForPath(const QDBusObjectPath &path) const
 {
-    for (ObexSessionPtr session : qAsConst(d->m_sessions)) {
+    for (ObexSessionPtr session : std::as_const(d->m_sessions)) {
         if (path.path().startsWith(session->objectPath().path())) {
             return session;
         }
@@ -90,8 +88,7 @@ PendingCall *ObexManager::registerAgent(ObexAgent *agent)
         qCDebug(BLUEZQT) << "Cannot register object" << agent->objectPath().path();
     }
 
-    return new PendingCall(d->m_obexAgentManager->RegisterAgent(agent->objectPath()),
-                           PendingCall::ReturnVoid, this);
+    return new PendingCall(d->m_obexAgentManager->RegisterAgent(agent->objectPath()), PendingCall::ReturnVoid, this);
 }
 
 PendingCall *ObexManager::unregisterAgent(ObexAgent *agent)
@@ -104,8 +101,7 @@ PendingCall *ObexManager::unregisterAgent(ObexAgent *agent)
 
     DBusConnection::orgBluezObex().unregisterObject(agent->objectPath().path());
 
-    return new PendingCall(d->m_obexAgentManager->UnregisterAgent(agent->objectPath()),
-                           PendingCall::ReturnVoid, this);
+    return new PendingCall(d->m_obexAgentManager->UnregisterAgent(agent->objectPath()), PendingCall::ReturnVoid, this);
 }
 
 PendingCall *ObexManager::createSession(const QString &destination, const QVariantMap &args)
@@ -114,8 +110,7 @@ PendingCall *ObexManager::createSession(const QString &destination, const QVaria
         return new PendingCall(PendingCall::InternalError, QStringLiteral("ObexManager not operational!"));
     }
 
-    return new PendingCall(d->m_obexClient->CreateSession(destination, args),
-                           PendingCall::ReturnObjectPath, this);
+    return new PendingCall(d->m_obexClient->CreateSession(destination, args), PendingCall::ReturnObjectPath, this);
 }
 
 PendingCall *ObexManager::removeSession(const QDBusObjectPath &session)
@@ -124,8 +119,9 @@ PendingCall *ObexManager::removeSession(const QDBusObjectPath &session)
         return new PendingCall(PendingCall::InternalError, QStringLiteral("ObexManager not operational!"));
     }
 
-    return new PendingCall(d->m_obexClient->RemoveSession(session),
-                           PendingCall::ReturnVoid, this);
+    return new PendingCall(d->m_obexClient->RemoveSession(session), PendingCall::ReturnVoid, this);
 }
 
 } // namespace BluezQt
+
+#include "moc_obexmanager.cpp"
